require "language/node"

class Octant < Formula
  desc "Kubernetes introspection tool for developers"
  homepage "https://octant.dev"
  url "https://github.com/vmware-tanzu/octant.git",
      tag:      "v0.25.1",
      revision: "f16cbb951905f1f8549469dfc116ca16cf679d46"
  license "Apache-2.0"
  head "https://github.com/vmware-tanzu/octant.git", branch: "master"

  # "VMware has ended active development of this project, this repository
  # will no longer be updated."
  deprecate! date: "2023-02-07", because: :repo_archived

  depends_on "go" => :build
  depends_on "node@14" => :build

  uses_from_macos "python" => :build

  on_linux do
    depends_on "pkg-config" => :build
  end

  def install
    ENV["GOFLAGS"] = "-mod=vendor"

    Language::Node.setup_npm_environment

    # Work around build error: "npm ERR! Invalid Version: ^3.0.8"
    # Issue is due to `npm-force-resolutions` not working with
    # npm>=8.6, which is used in node>=16 formulae.
    #
    # PR ref: https://github.com/vmware-tanzu/octant/pull/3311
    # Issue ref: https://github.com/vmware-tanzu/octant/issues/3329
    # Issue ref: https://github.com/rogeriochaves/npm-force-resolutions/issues/56
    ENV.prepend_path "PATH", Formula["node@14"].opt_bin
    cd "web" do
      system "npm", "install", *Language::Node.local_npm_install_args
    end

    system "go", "run", "build.go", "go-install"
    system "go", "run", "build.go", "web-build"

    ldflags = ["-X main.version=#{version}",
               "-X main.gitCommit=#{Utils.git_head}",
               "-X main.buildTime=#{time.iso8601}"].join(" ")

    tags = "embedded exclude_graphdriver_devicemapper exclude_graphdriver_btrfs containers_image_openpgp"

    system "go", "build", *std_go_args(ldflags: ldflags),
           "-tags", tags, "-v", "./cmd/octant"

    generate_completions_from_executable(bin/"octant", "completion")
  end

  test do
    fork do
      exec bin/"octant", "--kubeconfig", testpath/"config", "--disable-open-browser"
    end
    sleep 5

    output = shell_output("curl -s http://localhost:7777")
    assert_match "<title>Octant</title>", output, "Octant did not start"
    assert_match version.to_s, shell_output("#{bin}/octant version")
  end
end
